@@ -16,14 +16,12 @@
 #' @aliases canvasXpress-package
 "_PACKAGE"
 
-
 #' HTML Widget Creation
 #'
 #' Custom HTML widget creation function based on widget YAML and JavaScript for
 #' use in any html-compatible context
 #'
-#'
-#' @param data data.frame-, matrix-, or list- classed data object
+#' @param data data.frame-, matrix-, list- , or ggplot- classed object
 #' @param smpAnnot additional data that applies to samples (columns)
 #' @param varAnnot additional data that applies to variables (rows)
 #' @param graphType type of graph to be plotted - default = "Scatter2D"
@@ -36,72 +34,133 @@
 #' @param destroy used to indicate removal of a plot - default = FALSE
 #' @param ... additional parameters passed to canvasXpress
 #'
+#' @section Piping Support:
+#'   Piping is supported (both the magrittr '%>%' and native '|>' pipes) when sending an existing
+#'   canvasXpress object into data parameter.  Any new parameters will be added to the original configuration
+#'   of the object, any parameters with data that existed before will be replaced, and any parameters set
+#'   to null will be removed.  It is important to note that primary data changes are not allowed in this
+#'   construct - which means that anything specified by using the data, varAnnot, or smpAnnot parameters
+#'   cannot be changed from the original values.
+#'
 #' @return htmlwidgets object
 #'
 #' @export
-canvasXpress <- function(data = NULL,
-                         smpAnnot = NULL,
-                         varAnnot = NULL,
-                         #config items
-                         graphType = "Scatter2D",
-                         # straight-through
-                         events = NULL,
-                         afterRender=NULL,
-                         #htmlwidgets options
-                         pretty = FALSE,
-                         digits = 4,
-                         width  = 600,
-                         height = 400,
-                         destroy = FALSE,
-                         ... ) {
-
+canvasXpress <- function(data        = NULL,
+                         smpAnnot    = NULL,
+                         varAnnot    = NULL,
+                         graphType   = "Scatter2D",
+                         events      = NULL,
+                         afterRender = NULL,
+                         pretty      = FALSE,
+                         digits      = 4,
+                         width       = 600,
+                         height      = 400,
+                         destroy     = FALSE,
+                         ...) {
     if (destroy) {
         return(htmlwidgets::createWidget("canvasXpress", list()))
     }
 
     config <- list(graphType = graphType, isR = TRUE, ...)
 
-    if (is.null(data) || !("ggplot" %in% class(data))) {
+    if (is.null(data) || !(any(c("canvasXpress", "ggplot") %in% class(data)))) {
         assertDataCorrectness(data, graphType, config)
     }
 
-    x             <- NULL
-    y             <- NULL
-    z             <- NULL
-    dataframe     <- "columns"
-    precalc.box   <- c("iqr1", "qtl1", "median", "qtl3", "iqr3", "outliers")
-    precalc.bar   <- c("mean", "stdev")
+    x <- NULL
+    y <- NULL
+    z <- NULL
 
-    if (!is.null(data) && ("ggplot" %in% class(data))) {
+    dataframe   <- "columns"
+    precalc.box <- c("iqr1", "qtl1", "median", "qtl3", "iqr3", "outliers")
+    precalc.bar <- c("mean", "stdev")
+
+    if (!is.null(data) && "canvasXpress" %in% class(data)) {
+        # piped in object that will receive changes
+
+        if (!missing(smpAnnot) || !missing(varAnnot)) {
+            stop("Primary object data changes are not supported when modifying a canvasXpress object (ie piping) - ie changes to the data, varAnnot or smpAnnot parameters.")
+        }
+
+        if (is.null(data$x)) {
+            stop("Original canvasXpress object is invalid and cannot be read")
+        }
+
+        if (!is.null(data$x$config)) {
+            if (missing(graphType)) {
+                config$graphType = data$x$config$graphType
+            }
+            old_config <- data$x$config
+
+            # bring in old config values that are not specified in this object
+            for (c in names(old_config)) {
+                if (!c %in% names(config)) {
+                    config[c] <- old_config[c]
+                }
+            }
+        }
+
+        if (!is.null(data$x$events) && missing(events)) {
+            events <- data$x$events
+        }
+
+        if (!is.null(data$x$afterRender) && missing(afterRender)) {
+            afterRender <- data$x$afterRender
+        }
+
+        old_attr <- attr(data$x, "TOJSON_ARGS")
+        if (!is.null(old_attr)) {
+            if (missing(pretty) && !is.null(old_attr$pretty)) {
+                pretty <- old_attr$pretty
+            }
+
+            if (missing(digits) && !is.null(old_attr$digits)) {
+                digits <- old_attr$digits
+            }
+
+            if (!is.null(old_attr$dataframe)) {
+                dataframe <- old_attr$dataframe
+            }
+        }
+
+        if (missing(width)) {
+            width <- data$width
+        }
+
+        if (missing(height)) {
+            height <- data$height
+        }
+
+        cx_object <- list(data        = data$x$data,
+                          config      = config,
+                          events      = events,
+                          afterRender = afterRender)
+    } else if (!is.null(data) && ("ggplot" %in% class(data))) {
         if (!(requireNamespace("ggplot2", quietly = TRUE))) {
             stop("The ggplot2 package is required to use this functionality.")
         }
         cx_object <- ggplot.as.list(data, ...)
-    } else	if (is.character(data) && (graphType != "Network")) {
-		if (httr::http_error(data)) {
-		    message("Unable to validate URL")
-		}
-		# CanvasXpress Object
-		cx_object <- list(data        = data,
-				          config      = config,
-				          events      = events,
-				          afterRender = afterRender)
-	}
-	else if (graphType == "Venn") {
+    } else if (is.character(data) && (graphType != "Network")) {
+        if (httr::http_error(data)) {
+            message("Unable to validate URL")
+        }
+        # CanvasXpress Object
+        cx_object <- list(data        = data,
+                          config      = config,
+                          events      = events,
+                          afterRender = afterRender)
+    } else if (graphType == "Venn") {
         vdata <- NULL
         if (is.null(data)) {
             if (inherits(config$vennData, "list")) {
                 vdata <- config$vennData[[1]]
-            }
-            else {
+            } else {
                 vdata <- config$vennData
             }
-        }
-        else {
+        } else {
             if (inherits(data, "list")) {
                 vdata <- data[[1]]
-            }
-            else {
+            } else {
                 vdata <- data
             }
         }
@@ -115,43 +174,36 @@ canvasXpress <- function(data = NULL,
                           config      = config,
                           events      = events,
                           afterRender = afterRender)
-    }
-    else if (graphType == "Map" &&
-             (is.null(data) || (inherits(data, "logical") && data == FALSE))) {
-
+    } else if (graphType == "Map" && (is.null(data) || (inherits(data, "logical") && data == FALSE))) {
         # CanvasXpress Object
         cx_object <- list(data        = FALSE,
                           config      = config,
                           events      = events,
                           afterRender = afterRender)
-    }
-    else if (graphType == "Network") {
+    } else if (graphType == "Network") {
         if (is.character(data)) {
             if (file.exists(data)) {
-                data <- paste(readLines(data), collapse = '\n')
-            }
-            else if (httr::http_error(data)) {
+                data <- paste(readLines(data), collapse = "\n")
+            } else if (httr::http_error(data)) {
                 message(data, " may not a valid file location or URL - unable to verify.")
             }
 
-            #optionally read appendNetworkData for config
+            # optionally read appendNetworkData for config
             nd <- config$appendNetworkData
             if (!is.null(nd) && (is.list(nd) || is.character(nd))) {
-                nd <- as.list(nd)
+                nd     <- as.list(nd)
                 nd.new <- list()
                 for (x in nd) {
                     if (is.character(x)) {
                         if (file.exists(x)) {
-                            nd.new <- append(nd.new, paste(readLines(x), collapse = '\n'))
-                        }
-                        else {
+                            nd.new <- append(nd.new, paste(readLines(x), collapse = "\n"))
+                        } else {
                             if (httr::http_error(x)) {
                                 message("Unable to validate URL")
                             }
                             nd.new <- append(nd.new, x)
                         }
-                    }
-                    else {
+                    } else {
                         nd.new <- append(nd.new, list(x))
                     }
                 }
@@ -163,54 +215,56 @@ canvasXpress <- function(data = NULL,
                               config      = config,
                               events      = events,
                               afterRender = afterRender)
-
-        }
-        else {
-            ndata     <- NULL
-            edata     <- NULL
+        } else {
+            ndata <- NULL
+            edata <- NULL
+            gdata <- NULL
+            cdata <- NULL
             dataframe <- "rows"
 
             if (is.null(data)) {
-                ndata <- config$nodeData
-                edata <- config$edgeData
-                config <- config[!(names(config) %in% c("nodeData", "edgeData"))]
-            }
-            else {
+                ndata  <- config$nodeData
+                edata  <- config$edgeData
+                gdata  <- config$groupData
+                cdata  <- config$constraintData
+                config <- config[!(names(config) %in% c("nodeData", "edgeData", "groupData", "constraintData"))]
+            } else {
                 ndata <- data$nodeData
                 edata <- data$edgeData
+                gdata <- data$groupData
+                cdata <- data$constraintData
             }
 
             # CanvasXpress Object
-            cx_object <- list(data        = list(nodes = ndata, edges = edata),
+            cx_object <- list(data        = list(nodes       = ndata,
+                                                 edges       = edata,
+                                                 groups      = gdata,
+                                                 constraints = cdata),
                               config      = config,
                               events      = events,
                               afterRender = afterRender)
         }
-    }
-    else if (graphType == "Genome") {
+    } else if (graphType == "Genome") {
         cx_object <- list(data        = data,
                           config      = config,
                           events      = events,
                           afterRender = afterRender)
         digits <- 16
-    }
-    else if (graphType == "Boxplot" &&
-             ((length(intersect(names(data), precalc.box[1:5])) == 5) ||
-              (length(intersect(rownames(data), precalc.box[1:5])) == 5))) {
-
+    } else if (graphType == "Boxplot" &&
+               ((length(intersect(names(data), precalc.box[1:5])) == 5) ||
+                (length(intersect(rownames(data), precalc.box[1:5])) == 5))) {
         if (inherits(data, "list")) {
             data.names <- names(data)
-            iqr1       <- as.matrix(t(data[["iqr1"]]));   dimnames(iqr1)   <- NULL
-            iqr3       <- as.matrix(t(data[["iqr3"]]));   dimnames(iqr3)   <- NULL
-            median     <- as.matrix(t(data[["median"]])); dimnames(median) <- NULL
-            qtl1       <- as.matrix(t(data[["qtl1"]]));   dimnames(qtl1)   <- NULL
-            qtl3       <- as.matrix(t(data[["qtl3"]]));   dimnames(qtl3)   <- NULL
+            iqr1   <- as.matrix(t(data[["iqr1"]]));   dimnames(iqr1) <- NULL
+            iqr3   <- as.matrix(t(data[["iqr3"]]));   dimnames(iqr3) <- NULL
+            median <- as.matrix(t(data[["median"]])); dimnames(median) <- NULL
+            qtl1   <- as.matrix(t(data[["qtl1"]]));   dimnames(qtl1) <- NULL
+            qtl3   <- as.matrix(t(data[["qtl3"]]));   dimnames(qtl3) <- NULL
 
             if (!is.null(smpAnnot)) {
                 if (inherits(smpAnnot, "character")) {
                     smps <- smpAnnot
-                }
-                else {
+                } else {
                     smps <- rownames(smpAnnot)
                 }
             } else {
@@ -225,20 +279,19 @@ canvasXpress <- function(data = NULL,
                       qtl1   = qtl1,
                       qtl3   = qtl3)
             if ("outliers" %in% data.names) {
-                out <- t(as.matrix(data[["outliers"]]))
+                out     <- t(as.matrix(data[["outliers"]]))
                 out.new <- sapply(out, strsplit, ",")
                 out.new <- unname(sapply(out.new, as.numeric))
                 out.new <- sapply(out.new, as.list)
-                y$out <- list(out.new)
+                y$out   <- list(out.new)
             }
-        }
-        else {
+        } else {
             data.names <- rownames(data)
-            iqr1   <- as.matrix(data["iqr1",]);   dimnames(iqr1)   <- NULL
-            iqr3   <- as.matrix(data["iqr3",]);   dimnames(iqr3)   <- NULL
-            median <- as.matrix(data["median",]); dimnames(median) <- NULL
-            qtl1   <- as.matrix(data["qtl1",]);   dimnames(qtl1)   <- NULL
-            qtl3   <- as.matrix(data["qtl3",]);   dimnames(qtl3)   <- NULL
+            iqr1   <- as.matrix(data["iqr1", ]);   dimnames(iqr1) <- NULL
+            iqr3   <- as.matrix(data["iqr3", ]);   dimnames(iqr3) <- NULL
+            median <- as.matrix(data["median", ]); dimnames(median) <- NULL
+            qtl1   <- as.matrix(data["qtl1", ]);   dimnames(qtl1) <- NULL
+            qtl3   <- as.matrix(data["qtl3", ]);   dimnames(qtl3) <- NULL
 
             y <- list(smps   = as.list(assignCanvasXpressColnames(data)),
                       vars   = as.list("precalculated BoxPlot"),
@@ -249,11 +302,11 @@ canvasXpress <- function(data = NULL,
                       qtl3   = qtl3)
             if ("outliers" %in% data.names) {
                 if ("outliers" %in% data.names) {
-                    out <- t(as.matrix(data["outliers",]))
+                    out     <- t(as.matrix(data["outliers", ]))
                     out.new <- sapply(out, strsplit, ",")
                     out.new <- unname(sapply(out.new, as.numeric))
                     out.new <- sapply(out.new, as.list)
-                    y$out <- list(out.new)
+                    y$out   <- list(out.new)
                 }
             }
         }
@@ -283,41 +336,37 @@ canvasXpress <- function(data = NULL,
                           config      = config,
                           events      = events,
                           afterRender = afterRender)
-    }
-    else if (graphType == "Bar" &&
-             ((length(intersect(names(data), precalc.bar[1:2])) == 2) ||
-              (length(intersect(rownames(data), precalc.bar[1:2])) == 2))) {
-
+    } else if (graphType == "Bar" &&
+               ((length(intersect(names(data), precalc.bar[1:2])) == 2) ||
+                (length(intersect(rownames(data), precalc.bar[1:2])) == 2))) {
         if (inherits(data, "list")) {
             data.names <- names(data)
-            mean       <- as.matrix(t(data[["mean"]]));   dimnames(mean)   <- NULL
-            stdev      <- as.matrix(t(data[["stdev"]]));  dimnames(stdev)  <- NULL
+            mean  <- as.matrix(t(data[["mean"]]));  dimnames(mean) <- NULL
+            stdev <- as.matrix(t(data[["stdev"]])); dimnames(stdev) <- NULL
 
             if (!is.null(smpAnnot)) {
                 if (inherits(smpAnnot, "character")) {
                     smps <- smpAnnot
-                }
-                else {
+                } else {
                     smps <- rownames(smpAnnot)
                 }
             } else {
                 smps <- make.names(1:length(data[["mean"]]))
             }
 
-            y <- list(smps   = as.list(smps),
-                      vars   = as.list("precalculated BarChart"),
-                      mean   = mean,
-                      stdev  = stdev)
-        }
-        else {
+            y <- list(smps  = as.list(smps),
+                      vars  = as.list("precalculated BarChart"),
+                      mean  = mean,
+                      stdev = stdev)
+        } else {
             data.names <- rownames(data)
-            mean   <- as.matrix(data["mean",]);   dimnames(mean)   <- NULL
-            stdev  <- as.matrix(data["stdev",]);  dimnames(stdev)  <- NULL
+            mean  <- as.matrix(data["mean", ]);  dimnames(mean) <- NULL
+            stdev <- as.matrix(data["stdev", ]); dimnames(stdev) <- NULL
 
-            y <- list(smps   = as.list(assignCanvasXpressColnames(data)),
-                      vars   = as.list("precalculated BarChart"),
-                      mean   = mean,
-                      stdev  = stdev)
+            y <- list(smps  = as.list(assignCanvasXpressColnames(data)),
+                      vars  = as.list("precalculated BarChart"),
+                      mean  = mean,
+                      stdev = stdev)
         }
 
         if (!is.null(smpAnnot)) {
@@ -345,9 +394,8 @@ canvasXpress <- function(data = NULL,
                           config      = config,
                           events      = events,
                           afterRender = afterRender)
-    }
-    # standard graph
-    else {
+    } else {
+        # standard graph
         y <- setup_y(data)
         x <- setup_x(y$smps, smpAnnot)
         z <- setup_z(y$vars, varAnnot)
@@ -357,20 +405,20 @@ canvasXpress <- function(data = NULL,
                           config      = config,
                           events      = events,
                           afterRender = afterRender)
-    } #standard graph
+    } # standard graph
 
-    attr(cx_object, 'TOJSON_ARGS') <- list(dataframe = dataframe,
-                                           pretty    = pretty,
-                                           digits    = digits)
+    attr(cx_object, "TOJSON_ARGS") <- list(
+        dataframe = dataframe,
+        pretty    = pretty,
+        digits    = digits)
 
-    htmlwidgets::createWidget(name = "canvasXpress",
-                              cx_object,
-                              width  = width,
-                              height = height,
+    htmlwidgets::createWidget(name    = "canvasXpress",
+                              x       = cx_object,
+                              width   = width,
+                              height  = height,
                               package = "canvasXpress")
 }
 
-
 #' HTML Widget Creation using JSON input
 #'
 #' Custom HTML widget creation function based on widget YAML and JavaScript for
@@ -407,11 +455,10 @@ canvasXpress <- function(data = NULL,
 #'
 #' @export
 canvasXpress.json <- function(json,
-                              #htmlwidgets options
-                              pretty = FALSE,
-                              digits = 4,
-                              width  = 600,
-                              height = 400,
+                              pretty  = FALSE,
+                              digits  = 4,
+                              width   = 600,
+                              height  = 400,
                               destroy = FALSE) {
     if (destroy) {
         return(htmlwidgets::createWidget("canvasXpress", list()))
