@@ -77,8 +77,8 @@ test_that("segregated boxplot duplicated labels", {
                            smpAnnot              = precalc.data[c("type", "cnty"), ],
                            graphType             = "Boxplot",
                            graphOrientation      = "vertical",
-                           smpLabelFontStyle     = "italic",
-                           smpLabelRotate        = 90,
+                           smpTextFontStyle      = "italic",
+                           smpTextRotate         = 90,
                            showLegend            = FALSE,
                            segregateSamplesBy    = list("cnty"),
                            title                 = "Precalculated boxplot with segregation - data with smpAnnot",
@@ -96,8 +96,8 @@ test_that("boxplot duplicated labels", {
                            smpAnnot              = precalc.data["type", ],
                            graphType             = "Boxplot",
                            graphOrientation      = "vertical",
-                           smpLabelFontStyle     = "italic",
-                           smpLabelRotate        = 90,
+                           smpTextFontStyle      = "italic",
+                           smpTextRotate         = 90,
                            showLegend            = FALSE,
                            title                 = "Precalculated boxplot - data with smpAnnot",
                            titleScaleFontFactor  = 0.5)
