@@ -17,8 +17,8 @@ test_that("precalculated barplot - dataframe data", {
     result <- canvasXpress(data                  = precalc.data,
                            graphType             = "Bar",
                            graphOrientation      = "vertical",
-                           smpLabelFontStyle     = "italic",
-                           smpLabelRotate        = 90,
+                           smpTextFontStyle      = "italic",
+                           smpTextRotate         = 90,
                            showLegend            = FALSE,
                            title                 = "Precalculated barplot - data without smpAnnot",
                            titleScaleFontFactor  = 0.5)
@@ -29,8 +29,8 @@ test_that("precalculated barplot - dataframe data", {
                            smpAnnot              = smp.data,
                            graphType             = "Bar",
                            graphOrientation      = "vertical",
-                           smpLabelFontStyle     = "italic",
-                           smpLabelRotate        = 90,
+                           smpTextFontStyle      = "italic",
+                           smpTextRotate         = 90,
                            showLegend            = FALSE,
                            title                 = "Precalculated barplot - data with smpAnnot",
                            titleScaleFontFactor  = 0.5)
@@ -42,8 +42,8 @@ test_that("precalculated barplot - list data", {
     result <- canvasXpress(data                  =  precalc.data.l,
                            graphType             = "Bar",
                            graphOrientation      = "vertical",
-                           smpLabelFontStyle     = "italic",
-                           smpLabelRotate        = 90,
+                           smpTextFontStyle      = "italic",
+                           smpTextRotate         = 90,
                            showLegend            = FALSE,
                            title                 = "Precalculated barplot - list data without smpAnnot",
                            titleScaleFontFactor  = 0.5)
@@ -55,8 +55,8 @@ test_that("precalculated barplot - list data", {
                            smpAnnot              =  colnames(precalc.data),
                            graphType             = "Bar",
                            graphOrientation      = "vertical",
-                           smpLabelFontStyle     = "italic",
-                           smpLabelRotate        = 90,
+                           smpTextFontStyle      = "italic",
+                           smpTextRotate         = 90,
                            showLegend            = FALSE,
                            title                 = "Precalculated barplot - list data with smpAnnot",
                            titleScaleFontFactor  = 0.5)
@@ -68,8 +68,8 @@ test_that("precalculated barplot - list data", {
                            smpAnnot              = smp.data,
                            graphType             = "Bar",
                            graphOrientation      = "vertical",
-                           smpLabelFontStyle     = "italic",
-                           smpLabelRotate        = 90,
+                           smpTextFontStyle      = "italic",
+                           smpTextRotate         = 90,
                            showLegend            = FALSE,
                            title                 = "Precalculated barplot - list data with smpAnnot",
                            titleScaleFontFactor  = 0.5)
