@@ -12,3 +12,7 @@ test_that("cXcorrelation2", {
 test_that("cXcorrelation3", {
     check_ui_test(cXcorrelation3())
 })
+
+test_that("cXcorrelation4", {
+    check_ui_test(cXcorrelation4())
+})
